<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>PreviousView</name>
    <message>
        <location filename="../PreviousViewInit.js" line="+2"/>
        <source>&amp;Previous View</source>
        <translation>&amp;Předchozí pohled</translation>
    </message>
</context>
</TS>
